summaryrefslogtreecommitdiffstats
path: root/release
diff options
context:
space:
mode:
authorjkh <jkh@FreeBSD.org>1997-01-27 09:51:56 +0000
committerjkh <jkh@FreeBSD.org>1997-01-27 09:51:56 +0000
commit4747e960865efc706bace2562025079e9d787761 (patch)
treebc0993ff281792a4920a04192fe8bc991db1ef69 /release
parent63bae8ec19e886354ad093f81ec42f53de912f31 (diff)
downloadFreeBSD-src-4747e960865efc706bace2562025079e9d787761.zip
FreeBSD-src-4747e960865efc706bace2562025079e9d787761.tar.gz
DTRT with a release string of "none" and use the correct (updated)
mountpoint name for fixit. Submitted-By: joerg
Diffstat (limited to 'release')
-rw-r--r--release/sysinstall/cdrom.c2
-rw-r--r--release/sysinstall/install.c4
2 files changed, 3 insertions, 3 deletions
diff --git a/release/sysinstall/cdrom.c b/release/sysinstall/cdrom.c
index 6918ae2..443f39a 100644
--- a/release/sysinstall/cdrom.c
+++ b/release/sysinstall/cdrom.c
@@ -99,7 +99,7 @@ mediaInitCDROM(Device *dev)
if (readInfo &&
(DITEM_STATUS(attr_parse_file(cd_attr, string_concat(mountpoint, "/cdrom.inf"))) == DITEM_FAILURE ||
- !(cp = attr_match(cd_attr, "CD_VERSION")) || strcmp(cp, variable_get(VAR_RELNAME)))) {
+ !(cp = attr_match(cd_attr, "CD_VERSION")) || (strcmp(cp, variable_get(VAR_RELNAME)) && strcmp("none", variable_get(VAR_RELNAME))))) {
if (!cp)
msgConfirm("Unable to find a %s/cdrom.inf file.\n"
"Either this is not a FreeBSD CDROM, there is a problem with\n"
diff --git a/release/sysinstall/install.c b/release/sysinstall/install.c
index a567f8b..7c7a640 100644
--- a/release/sysinstall/install.c
+++ b/release/sysinstall/install.c
@@ -276,10 +276,10 @@ installFixitCDROM(dialogMenuItem *self)
break;
}
/* Since the fixit code expects everything to be in /mnt2, and the CDROM mounting stuff /cdrom, do
* a little kludge dance here..
*/
- if (symlink("/cdrom", "/mnt2")) {
+ if (symlink("/dist", "/mnt2")) {
msgConfirm("Unable to symlink /mnt2 to the CDROM mount point. Please report this\n"
"unexpected failure to bugs@freebsd.org.");
return DITEM_FAILURE;
@@ -276,10 +276,10 @@ installFixitCDROM(dialogMenuItem *self)
break;
}
- /* Since the fixit code expects everything to be in /mnt2, and the CDROM mounting stuff /cdrom, do
+ /* Since the fixit code expects everything to be in /mnt2, and the CDROM mounting stuff /dist, do
* a little kludge dance here..
*/
OpenPOWER on IntegriCloud